@@ -1,10 +1,13 @@
 import base64
+from contextlib import suppress
+from typing import Optional
 
-from flask import request
+from flask import request, Request, Response
 from flask import session as flask_session
 from flask_login import LoginManager
 from flask_login.utils import current_app, current_user, login_user
 from flask_restx import inputs
+from sqlalchemy.orm import Session
 from werkzeug.security import check_password_hash
 
 from flexget.api import api_app
@@ -18,42 +21,37 @@ login_manager.init_app(api_app)
 
 @login_manager.request_loader
 @with_session
-def load_user_from_request(request, session=None):
+def load_user_from_request(request: Request, session: Session = None) -> Optional[User]:
     auth_value = request.headers.get('Authorization')
 
     if not auth_value:
-        return
+        return None
 
     # Login using api key
     if auth_value.startswith('Token'):
-        try:
+        with suppress(TypeError, ValueError):
             token = auth_value.replace('Token ', '', 1)
             return session.query(User).filter(User.token == token).first()
-        except (TypeError, ValueError):
-            pass
 
     # Login using basic auth
     if auth_value.startswith('Basic'):
-        try:
-            credentials = base64.b64decode(auth_value.replace('Basic ', '', 1))
+        with suppress(TypeError, ValueError, UnicodeDecodeError):
+            credentials = base64.b64decode(auth_value.replace('Basic ', '', 1)).decode()
             username, password = credentials.split(':')
             user = session.query(User).filter(User.name == username).first()
             if user and user.password and check_password_hash(user.password, password):
                 return user
-            else:
-                return None
-        except (TypeError, ValueError):
-            pass
+    return None
 
 
 @login_manager.user_loader
 @with_session
-def load_user(username, session=None):
+def load_user(username: str, session: Session = None) -> Optional[User]:
     return session.query(User).filter(User.name == username).first()
 
 
 @api_app.before_request
-def check_valid_login():
+def check_valid_login() -> Optional[Response]:
     # Allow access to root, login and swagger documentation without authentication
     if (
         request.path == '/'
@@ -62,10 +60,11 @@ def check_valid_login():
         or request.path.startswith('/swagger')
         or request.method == 'OPTIONS'
     ):
-        return
+        return None
 
     if not current_user.is_authenticated:
         return current_app.login_manager.unauthorized()
+    return None
 
 
 # API Authentication and Authorization
@@ -97,7 +96,7 @@ class LoginAPI(APIResource):
     @api.response(Unauthorized)
     @api.response(200, 'Login successful', model=base_message_schema)
     @api.doc(parser=login_parser)
-    def post(self, session=None):
+    def post(self, session: Session = None) -> Response:
         """ Login with username and password """
         data = request.json
         user_name = data.get('username')
@@ -123,7 +122,7 @@ class LoginAPI(APIResource):
 @auth_api.route('/logout/')
 class LogoutAPI(APIResource):
     @api.response(200, 'Logout successful', model=base_message_schema)
-    def post(self, session=None):
+    def post(self, session: Session = None) -> Response:
         """ Logout and clear session cookies """
         flask_session.clear()
         resp = success_response('User logged out')
