@@ -1,19 +1,17 @@
 """
 Provides small event framework
 """
-from typing import Callable, List
+from typing import Callable, List, Dict, Any
 
 from loguru import logger
 
 logger = logger.bind(name='event')
 
-_events = {}
-
 
 class Event:
     """Represents one registered event."""
 
-    def __init__(self, name: str, func: Callable, priority: int = 128):
+    def __init__(self, name: str, func: Callable, priority: int = 128) -> None:
         self.name = name
         self.func = func
         self.priority = priority
@@ -31,11 +29,7 @@ class Event:
         return self.priority > other.priority
 
     def __str__(self):
-        return '<Event(name=%s,func=%s,priority=%s)>' % (
-            self.name,
-            self.func.__name__,
-            self.priority,
-        )
+        return f'<Event(name={self.name},func={self.func.__name__},priority={self.priority})>'
 
     __repr__ = __str__
 
@@ -43,10 +37,13 @@ class Event:
         return hash((self.name, self.func, self.priority))
 
 
+_events: Dict[str, List[Event]] = {}
+
+
 def event(name: str, priority: int = 128) -> Callable[[Callable], Callable]:
     """Register event to function with a decorator"""
 
-    def decorator(func):
+    def decorator(func: Callable) -> Callable:
         add_event_handler(name, func, priority)
         return func
 
@@ -86,19 +83,19 @@ def add_event_handler(name: str, func: Callable, priority: int = 128) -> Event:
     return event
 
 
-def remove_event_handlers(name: str):
+def remove_event_handlers(name: str) -> None:
     """Removes all handlers for given event `name`."""
     _events.pop(name, None)
 
 
-def remove_event_handler(name: str, func: Callable):
+def remove_event_handler(name: str, func: Callable) -> None:
     """Remove `func` from the handlers for event `name`."""
     for e in list(_events.get(name, [])):
         if e.func is func:
             _events[name].remove(e)
 
 
-def fire_event(name: str, *args, **kwargs):
+def fire_event(name: str, *args, **kwargs) -> Any:
     """
     Trigger an event with *name*. If event is not hooked by anything nothing happens. If a function that hooks an event
     returns a value, it will replace the first argument when calling next function.
