@@ -1,14 +1,10 @@
-from __future__ import unicode_literals, division, absolute_import
-from builtins import *  # noqa pylint: disable=unused-import, redefined-builtin
-from past.builtins import basestring
-
-import logging
+from loguru import logger
 
 from flexget import options, plugin
 from flexget.event import event
 from flexget.terminal import console
 
-log = logging.getLogger('dump')
+logger = logger.bind(name='dump')
 
 
 def dump(entries, debug=False, eval_lazy=False, trace=False, title_only=False):
@@ -30,10 +26,12 @@ def dump(entries, debug=False, eval_lazy=False, trace=False, title_only=False):
             return (1,)
         if field == 'original_url':
             return (2,)
-        return (3, field)
+        return 3, field
 
     for entry in entries:
         for field in sorted(entry, key=sort_key):
+            if field.startswith('_') and not debug:
+                continue
             if title_only and field != 'title':
                 continue
             if entry.is_lazy(field) and not eval_lazy:
@@ -43,7 +41,7 @@ def dump(entries, debug=False, eval_lazy=False, trace=False, title_only=False):
                     value = entry[field]
                 except KeyError:
                     value = '<LazyField - lazy lookup failed>'
-            if isinstance(value, basestring):
+            if isinstance(value, str):
                 try:
                     console('%-17s: %s' % (field, value.replace('\r', '').replace('\n', '')))
                 except Exception:
@@ -69,7 +67,7 @@ def dump(entries, debug=False, eval_lazy=False, trace=False, title_only=False):
             console('')
 
 
-class OutputDump(object):
+class OutputDump:
     """
     Outputs all entries to console
     """
@@ -123,8 +121,14 @@ def register_plugin():
 
 @event('options.register')
 def register_parser_arguments():
-    options.get_parser('execute').add_argument('--dump', nargs='*', choices=['eval', 'trace', 'accepted', 'rejected',
-                                                                             'undecided', 'title'], dest='dump_entries',
-                                               help=('display all entries in task with fields they contain, '
-                                                     'use `--dump eval` to evaluate all lazy fields. Specify an entry '
-                                                     'state/states to only dump matching entries.'))
+    options.get_parser('execute').add_argument(
+        '--dump',
+        nargs='*',
+        choices=['eval', 'trace', 'accepted', 'rejected', 'undecided', 'title'],
+        dest='dump_entries',
+        help=(
+            'display all entries in task with fields they contain, '
+            'use `--dump eval` to evaluate all lazy fields. Specify an entry '
+            'state/states to only dump matching entries.'
+        ),
+    )
