@@ -668,18 +668,14 @@ class SeriesParser(TitleParser):
         valid = 'INVALID'
         if self.valid:
             valid = 'OK'
-        return (
-            '<SeriesParser(data=%s,name=%s,id=%s,season=%s,season_pack=%s,episode=%s,quality=%s,proper=%s,'
-            'status=%s)>'
-            % (
-                self.data,
-                self.name,
-                str(self.id),
-                self.season,
-                self.season_pack,
-                self.episode,
-                self.quality,
-                self.proper_count,
-                valid,
-            )
+        return '<SeriesParser(data=%s,name=%s,id=%s,season=%s,season_pack=%s,episode=%s,quality=%s,proper=%s,' 'status=%s)>' % (
+            self.data,
+            self.name,
+            str(self.id),
+            self.season,
+            self.season_pack,
+            self.episode,
+            self.quality,
+            self.proper_count,
+            valid,
         )
